@@ -1,4 +1,4 @@
-/* TABLIX, PGA highschool timetable generator                              */
+/* TABLIX, PGA general timetable solver                              */
 /* Copyright (C) 2002-2004 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: counter.h,v 1.4 2004/09/24 13:57:03 avian Exp $ */
+/* $Id: counter.h,v 1.4.2.4 2005/09/02 19:30:42 avian Exp $ */
 
 #ifndef _COUNTER_H
 #define _COUNTER_H
@@ -25,8 +25,10 @@ extern int cnt_recv;
 extern int cnt_stopped;
 extern int cnt_total;
 
+void msg_flush();
 void counter_init();
-void counter_update(int sender, int grade, int mandatory, int gens);
+void counter_update(int sender, int fitness, int mandatory, int gens);
 void counter_clear();
 
+void msg_new(int sender, const char *fmt, ...);
 #endif
