@@ -1,4 +1,4 @@
-/* TABLIX, PGA highschool timetable generator                              */
+/* TABLIX, PGA general timetable solver                              */
 /* Copyright (C) 2004 Tomaz Solc                                           */
 
 /* This program is free software; you can redistribute it and/or modify    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: nodes.h,v 1.3 2004/06/11 20:20:52 avian Exp $ */
+/* $Id: nodes.h,v 1.3.4.2 2005/09/02 19:30:42 avian Exp $ */
 
 #ifndef _NODES_H
 #define _NODES_H
@@ -30,7 +30,7 @@ struct nodeinfos {
 int node_find(int tid);
 void node_stop(int num);
 void node_restart(int num);
-int node_startall(int nodereq);
+int node_startall(int nodereq, char **argv);
 void node_update(int node);
 
 extern int nodenum;
