@@ -1,4 +1,4 @@
-/* TABLIX, PGA highschool timetable generator                              */
+/* TABLIX, PGA general timetable solver                              */
 /* Copyright (C) 2002 Tomaz Solc                                           */
 
 /* This program is free software; you can redistribute it and/or modify    */
@@ -15,10 +15,20 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: xmlsup.h,v 1.4 2002/06/22 12:39:41 avian Exp $ */
+/* $Id: xmlsup.h,v 1.4.18.10 2005/09/02 19:30:42 avian Exp $ */
 
-void xmlsup_main();
-void xmlsup_addchromo(chromo *pop);
-void xmlsup_getchromo(chromo *pop);
-void xmlsup_dump(FILE *f);
-void xmlsup_exit();
+#ifndef _XMLSUP_H
+#define _XMLSUP_H
+
+/** @file */
+
+/** @brief Tablix Timetabling Model (XML configuration file format) version */
+#define PARSER_TTM_VERSION 	"0.2.0"
+
+int parser_main(char *filename);
+void parser_dump(FILE *f);
+void parser_exit();
+void parser_gettable(table *tab);
+void parser_addtable(table *tab);
+
+#endif
